@@ -10,7 +10,7 @@ use EPublisher::Config;
 use EPublisher::Source;
 use EPublisher::Target;
 
-our $VERSION = 0.9;
+our $VERSION = 1.1;
 
 sub new{
     my ($class,%args) = @_;
@@ -72,7 +72,7 @@ sub run{
             my @pod_source = $source_obj->load_source;
             @pod_source = ({ pod => '', title => '', filename => '' }) if !@pod_source;
             
-            $self->debug('101: ' . substr join( "", map{ $_->{pod} }@pod_source ), 0, 50 );
+            $self->debug('101: ' . substr join( "", map{ my $info = ( $_ ? $_ : {pod=>""} ); $_->{pod} }@pod_source ), 0, 50 );
             
             push @pods, @pod_source;
         }        
@@ -134,7 +134,7 @@ EPublisher - Publish documents in new format
 
 =head1 VERSION
 
-version 0.9
+version 1.1
 
 =head1 SYNOPSIS
 
